# Kahoot Api

A simple kahoot api to spam kahoot servers.

## Install

you can install the ```kahoot-api``` module by running this code:

```
$ pip3 install kahoot-api
```

## Usage

you can spam kahoot servers by using the ```spam()``` function:

```python
# import module
import kahoot-api

# spam
spam(name, code, amount)
```